@@ -11,8 +11,12 @@ use Text::CSV;
 use URI;
 # use URI::Escape qw{ uri_escape };
 
-our $VERSION = '0.006_01';
+our $VERSION = '0.008_01';
 
+use constant RETRACTION_MESSAGE =>
+	'Geo::Coder::Geocoder::US is being retracted, because the underlying web site no longer exists';
+
+Carp::cluck( RETRACTION_MESSAGE );
 {
 
 ##  my %valid_arg = map { $_ => 1 } qw{ debug interface ua };
@@ -20,6 +24,8 @@ our $VERSION = '0.006_01';
 
     sub new {
 	my ( $class, %args ) = @_;
+	carp( RETRACTION_MESSAGE );
+
 	ref $class
 	    and $class = ref $class;
 
@@ -316,7 +322,7 @@ Geo::Coder::Geocoder::US - Geocode a location using L<http://geocoder.us/>
      }
  }
 
-=head1 DEPRECATION NOTICE
+=head1 RETRACTION NOTICE
 
 This perl module makes use of the L<http://geocoder.us/> API to geocode
 addresses in the United States of America. This web site disappeared
@@ -324,15 +330,12 @@ late in 2015, and has not been seen since. Without the underlying web
 site, B<this code does nothing, and does it slowly since the query must
 time out.>
 
-Consequently, I am putting this module through a deprecation cycle.
-Currently, the installer warns when you install this module.  Beginning
-with the first release of 2017, the first call to L<new()|/new> will
-produce a warning (i.e. C<Carp::carp()>.) With the first release on or
-after July 1 2017, every call to L<new()|/new> will warn with stack
-trace (i.e.  C<Carp::cluck()>,) and it will warn when loaded. With the
-first release of 2018, loading this module will produce a fatal error.
-On or after the first of July 2018 I will delete this module from CPAN.
-It will still be available via BackPAN
+Consequently, I am putting this module through a retraction cycle.
+Currently, this module will warn with a stack trace when loaded, and on
+every call to C<new()|/new>. With the first release after June 1 2018,
+loading this module will produce a fatal error.  On or after the first
+of December 2018 I will delete this module from CPAN. It will still be
+available via BackPAN
 (L<http://backpan.perl.org/authors/id/W/WY/WYANT/>) or GitHub
 (L<https://github.com/trwyant/perl-Geo-Coder-Geocoder-US>.)
 
@@ -341,8 +344,8 @@ product key, you might try L<Geo::Coder::OSM|Geo::Coder::OSM>.
 
 =head1 DESCRIPTION
 
-B<This module is DEPRECATED.> See the
-L<DEPRECATION NOTICE|/DEPRECATION NOTICE> above.
+B<This module is RETRACTED.> See the
+L<RETRACTION NOTICE|/RETRACTION NOTICE> above.
 
 This package geocodes addresses by looking them up on the
 L<http://geocoder.us/> website. Because this site throttles access, this
@@ -443,7 +446,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2016 by Thomas R. Wyant, III
+Copyright (C) 2011-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
